==> qt-creator-opensource-src-4.7.1.zip: qt-creator-opensource-src-4.7.1/src/plugins/qmlprofiler/tests/qmlprofilerclientmanager_test.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/
#pragma once

#include <qmlprofiler/qmlprofilerclientmanager.h>
#include <qmlprofiler/qmlprofilermodelmanager.h>
#include <qmlprofiler/qmlprofilerstatemanager.h>

#include <QObject>

namespace QmlProfiler {
namespace Internal {

class QmlProfilerClientManagerTest : public QObject
{
    Q_OBJECT
public:
    explicit QmlProfilerClientManagerTest(QObject *parent = 0);

private slots:
    void testConnectionFailure_data();
    void testConnectionFailure();

    void testUnresponsiveTcp();
    void testUnresponsiveLocal();

    void testResponsiveTcp_data();
    void testResponsiveTcp();

    void testResponsiveLocal_data();
    void testResponsiveLocal();

    void testInvalidData();
    void testStopRecording();
    void testConnectionDrop();

private:
    QmlProfilerClientManager clientManager;
    QmlProfilerModelManager modelManager;
    QmlProfilerStateManager stateManager;

};

} // namespace Internal
} // namespace QmlProfiler

==> qt-creator-opensource-src-7.0.0.zip: qt-creator-opensource-src-7.0.0/src/plugins/qmlprofiler/tests/qmlprofilerclientmanager_test.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/
#pragma once

#include <qmlprofiler/qmlprofilerclientmanager.h>
#include <qmlprofiler/qmlprofilermodelmanager.h>
#include <qmlprofiler/qmlprofilerstatemanager.h>

#include <QObject>

namespace QmlProfiler {
namespace Internal {

class QmlProfilerClientManagerTest : public QObject
{
    Q_OBJECT
public:
    explicit QmlProfilerClientManagerTest(QObject *parent = nullptr);

private slots:
    void testConnectionFailure_data();
    void testConnectionFailure();

    void testUnresponsiveTcp();
    void testUnresponsiveLocal();

    void testResponsiveTcp_data();
    void testResponsiveTcp();

    void testResponsiveLocal_data();
    void testResponsiveLocal();

    void testInvalidData();
    void testStopRecording();
    void testConnectionDrop();

private:
    QmlProfilerClientManager clientManager;
    QmlProfilerModelManager modelManager;
    QmlProfilerStateManager stateManager;

};

} // namespace Internal
} // namespace QmlProfiler
